==> opennms-model-1.5.92-sources.jar: org/opennms/netmgt/model/EntityVisitor.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

public interface EntityVisitor {
	
	public void visitNode(OnmsNode node);
	public void visitNodeComplete(OnmsNode node);
	public void visitSnmpInterface(OnmsSnmpInterface snmpIface);
	public void visitSnmpInterfaceComplete(OnmsSnmpInterface snmpIface);
	public void visitIpInterface(OnmsIpInterface iface);
	public void visitIpInterfaceComplete(OnmsIpInterface iface);
	public void visitMonitoredService(OnmsMonitoredService monSvc);
	public void visitMonitoredServiceComplete(OnmsMonitoredService monSvc);

}

==> opennms-model-1.8.17-20120120.162530-45-sources.jar: org/opennms/netmgt/model/EntityVisitor.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified 
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
// OpenNMS Licensing       <license@opennms.org>
//     http://www.opennms.org/
//     http://www.opennms.com/
//
package org.opennms.netmgt.model;

/**
 * <p>EntityVisitor interface.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public interface EntityVisitor {
	
	/**
	 * <p>visitNode</p>
	 *
	 * @param node a {@link org.opennms.netmgt.model.OnmsNode} object.
	 */
	public void visitNode(OnmsNode node);
	/**
	 * <p>visitNodeComplete</p>
	 *
	 * @param node a {@link org.opennms.netmgt.model.OnmsNode} object.
	 */
	public void visitNodeComplete(OnmsNode node);
	/**
	 * <p>visitSnmpInterface</p>
	 *
	 * @param snmpIface a {@link org.opennms.netmgt.model.OnmsEntity} object.
	 */
	public void visitSnmpInterface(OnmsEntity snmpIface);
	/**
	 * <p>visitSnmpInterfaceComplete</p>
	 *
	 * @param snmpIface a {@link org.opennms.netmgt.model.OnmsEntity} object.
	 */
	public void visitSnmpInterfaceComplete(OnmsEntity snmpIface);
	/**
	 * <p>visitIpInterface</p>
	 *
	 * @param iface a {@link org.opennms.netmgt.model.OnmsIpInterface} object.
	 */
	public void visitIpInterface(OnmsIpInterface iface);
	/**
	 * <p>visitIpInterfaceComplete</p>
	 *
	 * @param iface a {@link org.opennms.netmgt.model.OnmsIpInterface} object.
	 */
	public void visitIpInterfaceComplete(OnmsIpInterface iface);
	/**
	 * <p>visitMonitoredService</p>
	 *
	 * @param monSvc a {@link org.opennms.netmgt.model.OnmsMonitoredService} object.
	 */
	public void visitMonitoredService(OnmsMonitoredService monSvc);
	/**
	 * <p>visitMonitoredServiceComplete</p>
	 *
	 * @param monSvc a {@link org.opennms.netmgt.model.OnmsMonitoredService} object.
	 */
	public void visitMonitoredServiceComplete(OnmsMonitoredService monSvc);

}
